@@ -64,6 +64,8 @@ BottomWidget::BottomWidget(QWidget *parent)
     this->setFocusPolicy(Qt::StrongFocus);
     this->setAttribute(Qt::WA_TranslucentBackground, true);//窗体标题栏不透明，背景透明
     this->setWindowFlags(windowFlags() | Qt::SubWindow | Qt::WindowStaysOnTopHint);
+//    this->setStyleSheet("QWidget{border: none; background-color: transparent; border-bottom-left-radius: 6px; border-bottom-right-radius: 6px;}");
+
     this->installEventFilter(this);
 
     m_controlWidget = new QWidget(this);
@@ -223,6 +225,7 @@ BottomWidget::BottomWidget(QWidget *parent)
     m_btnPlayPause->setToolTip(tr("Play / Pause"));
     m_btnNext->setToolTip(tr("Next"));
     m_btnSound->setToolTip(tr("Mute"));
+    m_btnFullScreen->setToolTip(tr("FullScreen"));
     m_btnPlayList->setToolTip(tr("Play List"));
 
     this->updateWidgetQssProperty(m_btnPlayPause, property_PlayStatus, playStatusPause);
