@@ -26,6 +26,8 @@
 #include <QFile>
 #include <QTextCodec>
 #include <QtDBus>
+#include <QDesktopWidget>
+#include <X11/Xlib.h>
 
 #include <signal.h>
 
@@ -35,18 +37,43 @@ int main(int argc, char **argv)
 {
     signal(SIGINT, [](int) { QApplication::quit(); });// 设置退出信号
 
-    MyApplication a("kylin-video", argc, argv );
-    a.setQuitOnLastWindowClosed(false);
+//#if (QT_VERSION <= QT_VERSION_CHECK(5,0,0))
+//    QTextCodec::setCodecForTr(QTextCodec::codecForLocale());
+//    QTextCodec::setCodecForCStrings(QTextCodec::codecForLocale());
+//    QTextCodec::setCodecForTr(QTextCodec::codecForName("UTF-8"));
+//    QTextCodec::setCodecForCStrings(QTextCodec::codecForName("UTF-8"));
+//#endif
+#if (QT_VERSION <= QT_VERSION_CHECK(5,0,0))
+    QTextCodec *codec = QTextCodec::codecForName("utf-8");
+    QTextCodec::setCodecForLocale(codec);
+    QTextCodec::setCodecForCStrings(codec);
+    QTextCodec::setCodecForTr(codec);
+#else
+    QTextCodec *codec = QTextCodec::codecForName("utf-8");
+    QTextCodec::setCodecForLocale(codec);
+#endif
 
+
+    QApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
+    QApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
+
+    MyApplication a("kylin-video", argc, argv );
+    a.setAttribute(Qt::AA_UseHighDpiPixmaps);
+    a.setQuitOnLastWindowClosed(false);
     a.setOrganizationName("kylin");
     a.setApplicationName("kylin-video");
-    a.setApplicationVersion("2.1.0");
+    a.setApplicationVersion("2.1.1");
 
 #if QT_VERSION >= 0x040400
-	// Enable icons in menus
-	QCoreApplication::setAttribute(Qt::AA_DontShowIconsInMenus, false);
+    // Enable icons in menus
+    QCoreApplication::setAttribute(Qt::AA_DontShowIconsInMenus, false);
 #endif
 
+//#if (QT_VERSION >= QT_VERSION_CHECK(5, 6, 0))
+//    QApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
+//#endif
+
+
     /*
     //----------------register controller dbus service----------------
     QDBusConnection connection = QDBusConnection::sessionBus();
