@@ -32,6 +32,10 @@
 #include "smplayer/preferences.h"
 #include "smplayer/core.h"
 
+#ifdef PREVIEW_TEST
+#include "previewmanager.h"
+#endif
+
 class QPushButton;
 class QWidget;
 class QMenu;
@@ -50,6 +54,7 @@ class TitleWidget;
 class BottomWidget;
 class PlayMask;
 class VideoPreview;
+class PreviewDialog;
 class BottomController;
 class FilterHandler;
 //class ShortcutsWidget;
@@ -207,6 +212,11 @@ public slots:
     void clearMplayerLog();
     void recordMplayerLog(QString line);
 
+#ifdef PREVIEW_TEST
+    void onStopPreview(int rc);
+    void onPausePreview();
+#endif
+
 signals:
     void requestActionsEnabled(bool);
     void requestPlayOrPauseEnabled(bool);
@@ -221,6 +231,7 @@ protected:
     bool event(QEvent * event) Q_DECL_OVERRIDE;
 	bool was_minimized;
 #endif
+    bool is_change_stat;
     void dragEnterEvent(QDragEnterEvent *event) Q_DECL_OVERRIDE;
     void dropEvent(QDropEvent *event) Q_DECL_OVERRIDE;
     void closeEvent(QCloseEvent *event) Q_DECL_OVERRIDE;
@@ -229,7 +240,7 @@ protected:
     void mouseMoveEvent(QMouseEvent *event) Q_DECL_OVERRIDE;
     bool eventFilter(QObject *obj, QEvent *event) Q_DECL_OVERRIDE;
     void resizeEvent(QResizeEvent *event) Q_DECL_OVERRIDE;
-    //    void paintEvent(QPaintEvent *event) Q_DECL_OVERRIDE;
+    void paintEvent(QPaintEvent *event) Q_DECL_OVERRIDE;
     void keyPressEvent(QKeyEvent *event) Q_DECL_OVERRIDE;
 
 private:
@@ -250,7 +261,6 @@ private:
     EscTip *m_escWidget = nullptr;
     TipWidget *m_tipWidget = nullptr;
     QTimer *m_tipTimer = nullptr;
-    VideoPreview *m_videoPreview = nullptr;
 //    ShortcutsWidget *m_shortcutsWidget;
     FilterHandler *m_mouseFilterHandler = nullptr;
 //    CoverWidget *m_coverWidget = nullptr;
@@ -432,6 +442,15 @@ private:
 //    MyAction *play_pause_aciton = nullptr;
     MyAction *stopAct = nullptr;
     MyAction *fullscreenAct = nullptr;
+
+#ifdef PREVIEW_TEST
+    QPointer<PreviewManager> m_previewMgr;
+    PreviewDialog *m_previewDlg = nullptr;
+#else
+    VideoPreview *m_videoPreview = nullptr;
+#endif
+
+    bool m_oldIsMaxmized;
 };
     
 #endif // _MAINWINDOW_H_
