@@ -897,6 +897,21 @@ bool Playlist::maybeSave()
 void Playlist::onPlayListItemDoubleClicked(int row, const QString &filename)
 {
     //playlist_filename = filename;
+    // lc add 20200831 判断是否为网络视频
+    if(filename.indexOf(QRegExp("^.*://.*")) != -1)
+    {
+        if ((row >= this->m_playlistView->getModelRowCount()) || (row < 0)) {
+            emit this->requestSetPlayingTitle("");
+            return;
+        }
+        emit this->requestSetPlayingTitle(filename);
+        //保存当前播放文件的索引和文件路径名
+        this->setPlaying(filename, row);
+        m_core->stop();
+        m_core->openStream(filename);
+        return;
+    }
+    // lc end
 
     QFileInfo fi(filename);
     if (fi.exists()) {
@@ -906,13 +921,16 @@ void Playlist::onPlayListItemDoubleClicked(int row, const QString &filename)
             return;
         }
 
+#ifdef PREVIEW_TEST
+        emit requestDestoryPreview();
+#endif
 
         QString name = fi.fileName();
         emit this->requestSetPlayingTitle(name);
 
         //保存当前播放文件的索引和文件路径名
         this->setPlaying(filename, row);
-
+        m_core->stop();
         m_core->open(filename/*, 0*/);//每次从头开始播放文件
     }
     else {
@@ -956,8 +974,22 @@ void Playlist::playItem( int n )
         return;
     }
 
+
     QString filename = this->m_playlistView->getFileNameByRow(n);
     if (!filename.isEmpty()) {
+        // lc add 20200901 如果为网络视频流单独处理
+        qDebug() << "====================" << filename;
+        if(filename.indexOf(QRegExp("^.*://.*")) != -1)
+        {
+            //保存当前播放文件的索引和文件路径名
+            this->setPlaying(filename, n);
+            emit this->requestSetPlayingTitle(filename);
+            m_core->stop();
+            m_core->open(filename, 0);
+            return;
+        }
+        // lc end
+
         QFileInfo fi(filename);
         if (fi.exists()) {
             //this->playlist_filename = filename;
@@ -1317,6 +1349,7 @@ void Playlist::addDirectory(QString dir)
 void Playlist::onPlayListItemDeleteBtnClicked(const QStringList &filepathlist)
 {
     if (!filepathlist.isEmpty()) {
+        QString playingFile = this->m_playlistView->getPlayingFile();
 //    if (!filename.isEmpty()) {
 //        MessageDialog msgDialog(0, tr("Confirm remove"),
 //                                tr("You're about to remove the file '%1' from the playlist.").arg(filename) + "<br>"+
@@ -1327,8 +1360,9 @@ void Playlist::onPlayListItemDeleteBtnClicked(const QStringList &filepathlist)
         if (msgDialog.exec() != -1) {
             if (msgDialog.standardButton(msgDialog.clickedButton()) == QMessageBox::Yes) {
                 if (set) {
-                    if (filepathlist.contains(this->m_playlistView->getPlayingFile())) {
+                    if (!playingFile.isEmpty() && filepathlist.contains(playingFile)) {
                         this->setPlaying("", 0);
+                        m_core->stop();//Fixed bug: #4915  将播放列表中正在播放的视频移除后，视频仍在播放
                     }
 
                     // Step 1: update pref->m_videoMap
@@ -1341,6 +1375,26 @@ void Playlist::onPlayListItemDeleteBtnClicked(const QStringList &filepathlist)
                         }
                     }
 
+                    //解决删除一个列表文件后，列表刷新后被选中的索引不正确的bug
+                    if (playingFile.isEmpty()) {
+                        this->m_currentItemIndex = 0;
+                    }
+                    else {
+                        if (filepathlist.contains(playingFile)) {
+                            this->m_currentItemIndex = 0;
+                        }
+                        else {
+                            int index = 0;
+                            QMap<QString, VideoPtr>::iterator i;
+                            for (i = pref->m_videoMap.begin(); i != pref->m_videoMap.end(); ++i) {
+                                if (playingFile == i.value()->localpath()) {
+                                    this->m_currentItemIndex = index;
+                                }
+                                index ++;
+                            }
+                        }
+                    }
+
                     // Step 2: update settings
                     set->remove("playlist_contents");
                     set->beginGroup("playlist_contents");
@@ -1369,7 +1423,16 @@ void Playlist::onPlayListItemDeleteBtnClicked(const QStringList &filepathlist)
                     if (!this->rowIsEmpty()) {//if (m_playlistView->getModelRowCount() > 0) {
                         noVideoFrame->hide();
                         this->m_playlistView->show();
-                        this->playNext();//Fixed bug: #4915
+                        QString state = m_core->stateToString().toUtf8().data();
+                        if (state == "Playing" || state == "Paused") {
+                            //当视频正在播放或者暂停时，继续保持该视频对应的播放列表项处于被选中的状态
+                            if (playingFile.isEmpty()) {
+                                this->setPlaying("", 0);//this->playNext();
+                            }
+                            else {
+                                this->setPlaying(playingFile, this->m_currentItemIndex);
+                            }
+                        }
                         emit this->update_playlist_count(pref->m_videoMap.count());
                     }
                     else {
