@@ -34,14 +34,14 @@ void MediaSettings::reset() {
 //    qDebug("MediaSettings::reset");
 
 	current_sec = 0;
+    current_subtitle_track = NoneSelected;
 	//current_sub_id = SubNone; 
-	current_sub_id = NoneSelected;
+//	current_sub_id = NoneSelected;
 //#ifdef MPV_SUPPORT
 //	current_secondary_sub_id = NoneSelected;
+    current_secondary_subtitle_track = NoneSelected;
 //#endif
-//#if PROGRAM_SWITCH
-//	current_program_id = NoneSelected;
-//#endif
+
 	current_video_id = NoneSelected;
 	current_audio_id = NoneSelected;
 	current_title_id = NoneSelected;
@@ -51,26 +51,26 @@ void MediaSettings::reset() {
 	aspect_ratio_id = AspectAuto;
 
 	//fullscreen = false;
-    volume = 40;//pref->initial_volume;
+    volume = pref->initial_volume;//40
 	mute = false;
 	external_subtitles = "";
 	external_subtitles_fps = SFPS_None;
 	external_audio = "";
 	sub_delay=0;
 	audio_delay=0;
-    sub_pos = 100;//pref->initial_sub_pos; // 100% by default
-    sub_scale = 5;//pref->initial_sub_scale;
-    sub_scale_ass = 1;//pref->initial_sub_scale_ass;
+    sub_pos = pref->initial_sub_pos; // 100% by default
+    sub_scale = pref->initial_sub_scale;
+    sub_scale_ass = pref->initial_sub_scale_ass;
 
 	closed_caption_channel = 0; // disabled
 
-    brightness = 0;//pref->initial_brightness;
-    contrast = 0;//pref->initial_contrast;
-    gamma = 0;//pref->initial_gamma;
-    hue = 0;//pref->initial_hue;
-    saturation = 0;//pref->initial_saturation;
+    brightness = pref->initial_brightness;
+    contrast = pref->initial_contrast;
+    gamma = pref->initial_gamma;
+    hue = pref->initial_hue;
+    saturation = pref->initial_saturation;
 
-//	audio_equalizer = pref->initial_audio_equalizer;
+    audio_equalizer = pref->initial_audio_equalizer;
 
 	speed = 1.0;
 
@@ -87,9 +87,9 @@ void MediaSettings::reset() {
 	stereo3d_in = "none";
 	stereo3d_out = QString::null;
 
-    current_deinterlacer = NoDeinterlace;//pref->initial_deinterlace;
+    current_deinterlacer = pref->initial_deinterlace;//NoDeinterlace
 
-	add_letterbox = false;
+    add_letterbox = pref->initial_blackborders;//add_letterbox = false;
 
 //#ifdef MPLAYER_SUPPORT
 	karaoke_filter = false;
@@ -97,12 +97,19 @@ void MediaSettings::reset() {
 //#endif
 	volnorm_filter = pref->initial_volnorm;
 
+//#ifdef MPV_SUPPORT
+    earwax_filter = false;
+//#endif
+
+
     audio_use_channels = pref->initial_audio_channels; //ChDefault; // (0)
-    stereo_mode = MediaSettings::Stereo;//pref->initial_stereo_mode; //Stereo; // (0)
+    stereo_mode = pref->initial_stereo_mode; //Stereo; // (0)
 
-    zoom_factor = 1.0;//pref->initial_zoom_factor; // 1.0;
+    zoom_factor = pref->initial_zoom_factor; // 1.0;
 
-	starting_time = -1; // Not set yet.
+//#ifdef MSET_USE_STARTING_TIME
+//	starting_time = -1; // Not set yet.
+//#endif
 
 	rotate = NoRotate;
 	flip = false;
@@ -114,8 +121,8 @@ void MediaSettings::reset() {
 
 //#ifdef BOOKMARKS
 //	// Initialize bookmarks
-//	bookmarks.clear();
-//	bookmarks.insert(0, "");
+    bookmarks.clear();
+    bookmarks.insert(0, "");
 //#endif
 
 	is264andHD = false;
@@ -132,12 +139,16 @@ void MediaSettings::reset() {
 	original_video_codec="";
 	original_audio_codec="";
 
-//    mplayer_additional_options="";
-//	mplayer_additional_video_filters="";
-//	mplayer_additional_audio_filters="";
+    mplayer_additional_options="";
+    mplayer_additional_video_filters="";
+    mplayer_additional_audio_filters="";
 
 	win_width=400;
 	win_height=300;
+
+    videos.clear();
+    audios.clear();
+    subs.clear();
 }
 
 double MediaSettings::win_aspect() {
@@ -161,7 +172,7 @@ double MediaSettings::aspectToNum(Aspect aspect) {
 		case MediaSettings::Aspect118: asp = (double) 11 / 8; break;
 		case MediaSettings::AspectAuto: asp = win_aspect(); break;
 		default: asp = win_aspect(); 
-//                 qWarning("MediaSettings::aspectToNum: invalid aspect: %d", aspect);
+                 qWarning("MediaSettings::aspectToNum: invalid aspect: %d", aspect);
 	}
 
 	return asp;
@@ -197,9 +208,7 @@ void MediaSettings::list() {
 ////#ifdef MPV_SUPPORT
 ////	qDebug("  current_secondary_sub_id: %d", current_secondary_sub_id);
 ////#endif
-//#if PROGRAM_SWITCH
-//	qDebug("  current_program_id: %d", current_program_id);
-//#endif
+
 //	qDebug("  current_video_id: %d", current_video_id);
 //	qDebug("  current_audio_id: %d", current_audio_id);
 //	qDebug("  current_title_id: %d", current_title_id);
@@ -285,6 +294,15 @@ void MediaSettings::list() {
 
 //	qDebug("  starting_time: %f", starting_time);
 //	qDebug("  is264andHD: %d", is264andHD);
+
+//    qDebug("  Videos:");
+    videos.list();
+
+//    qDebug("  Audios:");
+    audios.list();
+
+//    qDebug("  Subtitles:");
+    subs.list();
 }
 
 //#ifndef NO_USE_INI_FILES
@@ -304,19 +322,18 @@ void MediaSettings::save(QSettings * set, int player_id) {
 
 	// Save the tracks ID in a demuxer section
 	QString demuxer_section = QString("demuxer_%1").arg(current_demuxer);
-
 	if (!forced_demuxer.isEmpty()) {
 		demuxer_section = QString("demuxer_%1").arg(forced_demuxer);
 	}
 
 	set->beginGroup(demuxer_section);
-	set->setValue( "current_sub_id", current_sub_id );
+    set->setValue( "current_subtitle_track", current_subtitle_track );
+//	set->setValue( "current_sub_id", current_sub_id );
 //	#ifdef MPV_SUPPORT
 //	set->setValue( "current_secondary_sub_id", current_secondary_sub_id );
+    set->setValue( "current_secondary_subtitle_track", current_secondary_subtitle_track );
 //	#endif
-//	#if PROGRAM_SWITCH
-//	set->setValue( "current_program_id", current_program_id );
-//	#endif
+
 	set->setValue( "current_video_id", current_video_id );
 	set->setValue( "current_audio_id", current_audio_id );
 	set->endGroup();
@@ -351,7 +368,7 @@ void MediaSettings::save(QSettings * set, int player_id) {
 	set->setValue( "hue", hue);
 	set->setValue( "saturation", saturation);
 
-//	set->setValue("audio_equalizer", audio_equalizer );
+    set->setValue("audio_equalizer", audio_equalizer );
 
 	set->setValue( "speed", speed);
 
@@ -378,6 +395,10 @@ void MediaSettings::save(QSettings * set, int player_id) {
 //#endif
 	set->setValue( "volnorm_filter", volnorm_filter);
 
+//#ifdef MPV_SUPPORT
+    set->setValue( "earwax_filter", earwax_filter);
+//#endif
+
 	set->setValue( "audio_use_channels", audio_use_channels);
 	set->setValue( "stereo_mode", stereo_mode);
 
@@ -392,34 +413,39 @@ void MediaSettings::save(QSettings * set, int player_id) {
 	set->setValue( "B_marker", B_marker);
 
 //#ifdef BOOKMARKS
-//	// Save bookmarks
-//	bool save_bookmarks = true;
-//	QMap<int, QString>::const_iterator i = bookmarks.constBegin();
-//	if (bookmarks.count() == 1 && i.key() == 0) save_bookmarks = false;
-//	if (save_bookmarks) {
-//		set->beginWriteArray("bookmarks");
-//		int count = 0;
-//		while (i != bookmarks.constEnd()) {
-//			set->setArrayIndex(count);
-//			set->setValue("time", i.key());
-//			set->setValue("name", i.value());
-//			i++;
-//			count++;
-//		}
-//		set->endArray();
-//	}
+    // Save bookmarks
+    bool save_bookmarks = true;
+    QMap<int, QString>::const_iterator i = bookmarks.constBegin();
+    if (bookmarks.count() == 1 && i.key() == 0) save_bookmarks = false;
+    if (save_bookmarks) {
+        set->beginWriteArray("bookmarks");
+        int count = 0;
+        while (i != bookmarks.constEnd()) {
+            set->setArrayIndex(count);
+            set->setValue("time", i.key());
+            set->setValue("name", i.value());
+            i++;
+            count++;
+        }
+        set->endArray();
+    }
 //#endif
 
-//    set->setValue( "mplayer_additional_options", mplayer_additional_options);
-//	set->setValue( "mplayer_additional_video_filters", mplayer_additional_video_filters);
-//	set->setValue( "mplayer_additional_audio_filters", mplayer_additional_audio_filters);
+    set->setValue( "mplayer_additional_options", mplayer_additional_options);
+    set->setValue( "mplayer_additional_video_filters", mplayer_additional_video_filters);
+    set->setValue( "mplayer_additional_audio_filters", mplayer_additional_audio_filters);
 
 	set->setValue( "win_width", win_width );
 	set->setValue( "win_height", win_height );
-
-	set->setValue( "starting_time", starting_time );
-
+//#ifdef MSET_USE_STARTING_TIME
+//	set->setValue( "starting_time", starting_time );
+//#endif
 	set->setValue( "is264andHD", is264andHD );
+
+    // Save tracks
+    videos.save(set, "videotracks");
+    audios.save(set, "audiotracks");
+    subs.save(set, "subtitletracks");
 }
 
 void MediaSettings::load(QSettings * set, int player_id) {
@@ -439,7 +465,6 @@ void MediaSettings::load(QSettings * set, int player_id) {
 
 	// Load the tracks ID from a demuxer section
 	QString demuxer_section = QString("demuxer_%1").arg(current_demuxer);
-
 	if (!forced_demuxer.isEmpty()) {
 		demuxer_section = QString("demuxer_%1").arg(forced_demuxer);
 	}
@@ -447,13 +472,13 @@ void MediaSettings::load(QSettings * set, int player_id) {
 //	qDebug("MediaSettings::load: demuxer_section: %s", demuxer_section.toUtf8().constData());
 
 	set->beginGroup(demuxer_section);
-	current_sub_id = set->value( "current_sub_id", NoneSelected ).toInt();
+    current_subtitle_track = set->value( "current_subtitle_track", NoneSelected ).toInt();
+//	current_sub_id = set->value( "current_sub_id", NoneSelected ).toInt();
 //	#ifdef MPV_SUPPORT
 //	current_secondary_sub_id = set->value( "current_secondary_sub_id", NoneSelected ).toInt();
+    current_secondary_subtitle_track = set->value( "current_secondary_subtitle_track", NoneSelected ).toInt();
 //	#endif
-//	#if PROGRAM_SWITCH
-//	current_program_id = set->value( "current_program_id", NoneSelected ).toInt();
-//	#endif
+
 	current_video_id = set->value( "current_video_id", NoneSelected ).toInt();
 	current_audio_id = set->value( "current_audio_id", NoneSelected ).toInt();
 	set->endGroup();
@@ -488,7 +513,7 @@ void MediaSettings::load(QSettings * set, int player_id) {
 	hue = set->value( "hue", hue).toInt();
 	saturation = set->value( "saturation", saturation).toInt();
 
-//	audio_equalizer = set->value("audio_equalizer", audio_equalizer ).toList();
+    audio_equalizer = set->value("audio_equalizer", audio_equalizer ).toList();
 
 	speed = set->value( "speed", speed ).toDouble();
 
@@ -514,6 +539,9 @@ void MediaSettings::load(QSettings * set, int player_id) {
 	extrastereo_filter = set->value( "extrastereo_filter", extrastereo_filter).toBool();
 //#endif
 	volnorm_filter = set->value( "volnorm_filter", volnorm_filter).toBool();
+//#ifdef MPV_SUPPORT
+    earwax_filter = set->value( "earwax_filter", earwax_filter).toBool();
+//#endif
 
 	audio_use_channels = set->value( "audio_use_channels", audio_use_channels).toInt();
 	stereo_mode = set->value( "stereo_mode", stereo_mode).toInt();
@@ -529,33 +557,49 @@ void MediaSettings::load(QSettings * set, int player_id) {
 	B_marker = set->value( "B_marker", B_marker).toInt();
 
 //#ifdef BOOKMARKS
-//	// Load bookmarks
-//	int n_bookmarks = set->beginReadArray("bookmarks");
-//	if (n_bookmarks > 0) {
-//		bookmarks.clear();
-//		for (int i = 0; i < n_bookmarks; ++i) {
-//			set->setArrayIndex(i);
-//			int time = set->value("time").toInt();
-//			QString name = set->value("name").toString();
-//			bookmarks.insert(time, name);
-//		}
-//	}
-//	set->endArray();
+    // Load bookmarks
+    int n_bookmarks = set->beginReadArray("bookmarks");
+    if (n_bookmarks > 0) {
+        bookmarks.clear();
+        for (int i = 0; i < n_bookmarks; ++i) {
+            set->setArrayIndex(i);
+            int time = set->value("time").toInt();
+            QString name = set->value("name").toString();
+            bookmarks.insert(time, name);
+        }
+    }
+    set->endArray();
 //#endif
 
-//    mplayer_additional_options = set->value( "mplayer_additional_options", mplayer_additional_options).toString();
-//	mplayer_additional_video_filters = set->value( "mplayer_additional_video_filters", mplayer_additional_video_filters).toString();
-//	mplayer_additional_audio_filters = set->value( "mplayer_additional_audio_filters", mplayer_additional_audio_filters).toString();
+    mplayer_additional_options = set->value( "mplayer_additional_options", mplayer_additional_options).toString();
+    mplayer_additional_video_filters = set->value( "mplayer_additional_video_filters", mplayer_additional_video_filters).toString();
+    mplayer_additional_audio_filters = set->value( "mplayer_additional_audio_filters", mplayer_additional_audio_filters).toString();
 
 	win_width = set->value( "win_width", win_width ).toInt();
 	win_height = set->value( "win_height", win_height ).toInt();
 
-	starting_time = set->value( "starting_time", starting_time ).toDouble();
+//#ifdef MSET_USE_STARTING_TIME
+//	starting_time = set->value( "starting_time", starting_time ).toDouble();
+//#endif
 
 	is264andHD = set->value( "is264andHD", is264andHD ).toBool();
 
 	// ChDefault not used anymore
 	if (audio_use_channels == ChDefault) audio_use_channels = ChStereo;
+
+    // Load tracks
+    videos.load(set, "videotracks");
+    audios.load(set, "audiotracks");
+    subs.load(set, "subtitletracks");
+
+    //qDebug("MediaSettings::load: list of video tracks:");
+    videos.list();
+
+    //qDebug("MediaSettings::load: list of audio tracks:");
+    audios.list();
+
+    //qDebug("MediaSettings::load: list of subtitle tracks:");
+    subs.list();
 }
 
 //#endif // NO_USE_INI_FILES
