@@ -37,16 +37,14 @@ QString Paths::appPath() {
 
 QString Paths::translationPath()
 {
-    return ":/qm/translations";
-
-    /*QString path;
+    QString path;
     if (QDir("/usr/share/kylin-video/translations").exists()) {
         path = "/usr/share/kylin-video/translations";
         return path;
     }
     else {
         return appPath() + "/translations";
-    }*/
+    }
 }
 
 QString Paths::shortcutsPath() {
@@ -54,7 +52,11 @@ QString Paths::shortcutsPath() {
 }
 
 QString Paths::qtTranslationPath() {
-    return QLibraryInfo::location(QLibraryInfo::TranslationsPath);
+    //edited by kobe 20180623
+    /*if (app_path.startsWith("/snap/kylin-video/"))// /snap/kylin-video/x1/usr/bin
+        return "/snap/kylin-video/current" + QLibraryInfo::location(QLibraryInfo::TranslationsPath);// /snap/kylin-video/current/usr/share/qt5/translations
+    else*/
+    return QLibraryInfo::location(QLibraryInfo::TranslationsPath);// /usr/share/qt5/translations
 }
 
 void Paths::setConfigPath(QString path) {
@@ -75,3 +77,7 @@ QString Paths::configPath() {
 QString Paths::iniPath() {
 	return configPath();
 }
+
+QString Paths::subtitleStyleFile() {
+    return configPath() + "/styles.ass";
+}
