@@ -266,17 +266,29 @@ static QStringList modToString(Qt::KeyboardModifiers k)
 ShortcutGetter::ShortcutGetter(/*bool isbtn, */QWidget *parent) : QDialog(parent)
   , m_dragState(NOT_DRAGGING)
   , m_startDrag(QPoint(0,0))
+  , m_centerWidget(new QWidget(this))
 {
+    is_clear_clicked = false;
     this->setWindowFlags(Qt::Dialog | Qt::FramelessWindowHint);
     this->setFixedSize(438, 320);
-    this->setStyleSheet("QDialog{border: 1px solid #121212;border-radius:1px;background-color:#1f1f1f;}");
+    this->setAutoFillBackground(true);
+    this->setAttribute(Qt::WA_TranslucentBackground);//设置窗口背景透明
+//    this->setStyleSheet("QDialog{border: 1px solid #121212;border-radius:1px;background-color:#1f1f1f;}");
     this->setWindowIcon(QIcon::fromTheme("kylin-video", QIcon(":/res/kylin-video.png")));
 //    this->setWindowIcon(QIcon::fromTheme("kylin-video", QIcon(":/res/kylin-video.png")).pixmap(QSize(64, 64)).scaled(64, 64, Qt::IgnoreAspectRatio, Qt::SmoothTransformation));
-    this->setAutoFillBackground(true);
+
     this->setMouseTracking(true);
 	setWindowTitle(tr("Modify shortcut"));
 
-	QVBoxLayout *vbox = new QVBoxLayout(this);
+    //TODO: 无效
+    this->setObjectName("popDialog");
+    //this->setStyleSheet("QDialog#prefrecesdialog{border: 1px solid #121212;border-radius:6px;background-color:#1f1f1f;}");
+
+    m_centerWidget->setGeometry(0,0,this->width(),this->height());
+    m_centerWidget->setAutoFillBackground(true);
+    m_centerWidget->setObjectName("centerWidget");
+
+    QVBoxLayout *vbox = new QVBoxLayout(m_centerWidget);
 	vbox->setMargin(2);
     vbox->setSpacing(10);
     vbox->setContentsMargins(5,5,5,5);
@@ -375,6 +387,7 @@ ShortcutGetter::ShortcutGetter(/*bool isbtn, */QWidget *parent) : QDialog(parent
 	connect( buttonbox, SIGNAL(accepted()), this, SLOT(accept()) );
 	connect( buttonbox, SIGNAL(rejected()), this, SLOT(reject()) );
 	connect( clearbutton, SIGNAL(clicked()), leKey, SLOT(clear()) );
+    connect( clearbutton, SIGNAL(clicked()), this, SLOT(clear()) );
 	vbox->addWidget(buttonbox);
 }
 
@@ -393,6 +406,15 @@ void ShortcutGetter::rowChanged(int row) {
 
 // Added by rvm
 void ShortcutGetter::textChanged(const QString & text) {
+    for (int i = 0; i < list->count(); ++i) {
+        if (text == list->item(i)->text())
+            return;
+    }
+    for (auto &s : allAccelText) {
+        if (text == s && text != "") {
+            return;
+        }
+    }
 	list->item(list->currentRow())->setText(text);
 }
 
@@ -406,17 +428,24 @@ void ShortcutGetter::addItemClicked() {
 // Added by rvm
 void ShortcutGetter::removeItemClicked() {
 	qDebug("ShortcutGetter::removeItemClicked");
+    is_clear_clicked = true;
 	if (list->count() > 1) {
 		QListWidgetItem * i = list->takeItem( list->currentRow() );
 		if (i) delete i;
 	} else {
 		list->setCurrentRow(0);
 		leKey->setText("");
-	}
+    }
 }
 
-QString ShortcutGetter::exec(const QString& s)
+void ShortcutGetter::clear()
 {
+    is_clear_clicked = true;
+}
+
+QString ShortcutGetter::exec(const QString& s, const QStringList& sl)
+{
+    allAccelText = sl;
 	// Added by rvm
 	QStringList shortcuts = s.split(", ");
 	QString shortcut;
@@ -455,43 +484,39 @@ bool ShortcutGetter::event(QEvent *e)
 			
 	switch ( e->type() )
 	{
-		case QEvent::KeyPress :
+    case QEvent::KeyPress :
 					
-		if ( bStop )
-		{
-			lKeys.clear();
-			bStop = false;
-		}
+        if ( bStop ) {
+            lKeys.clear();
+            bStop = false;
+        }
+        break;
+					
+    case QEvent::KeyRelease :
 
-		key = keyToString(k->key());
-		mods = modToString(k->modifiers());
+        bStop = true;
+        key = keyToString(k->key());
+        if (key == "")
+            break;
+        mods = modToString(k->modifiers());
 
-		//qDebug("event: key.count: %d, mods.count: %d", key.count(), mods.count());
+        if ( key.count() || mods.count() ) {
 
-		if ( key.count() || mods.count() )
-		{
-						
-			if ( key.count() && !lKeys.contains(key) )
-				lKeys << key;
-						
-			foreach ( key, mods )
-				if ( !lKeys.contains(key) )
-					lKeys << key;
-			
-			} else {
-				key = k->text();
-						
-				if ( !lKeys.contains(key) )
-					lKeys << key;
-			}
-					
-			setText();
-			break;
-					
-		case QEvent::KeyRelease :
-					
-			bStop = true;
-			break;
+            if ( key.count() && !lKeys.contains(key) )
+                lKeys << key;
+
+            foreach ( key, mods )
+                if ( !lKeys.contains(key) )
+                    lKeys << key;
+        } else {
+            key = k->text();
+
+            if ( !lKeys.contains(key) )
+                lKeys << key;
+        }
+
+        setText();
+        break;
 					
 			/*
 		case QEvent::ShortcutOverride :
